@@ -1,4 +1,4 @@
-grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD", "gMCP", "gBridge", "gLasso"), family=c("gaussian","binomial"), nlambda=100, lambda, lambda.min={if (nrow(X) > ncol(X)) 1e-4 else .05}, alpha=1, eps=.005, max.iter=1000, dfmax=p, gamma = 3, group.multiplier=rep(1,J), warn=TRUE, ...)
+grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD", "gMCP", "gBridge", "gLasso"), family=c("gaussian","binomial"), nlambda=100, lambda, lambda.min={if (nrow(X) > ncol(X)) 1e-4 else .05}, alpha=1, eps=.005, max.iter=1000, dfmax=p, gamma = 3, group.multiplier={if (strtrim(penalty,2)=="gr") sqrt(table(group[group!=0])) else rep(1,J)}, warn=TRUE, ...)
 {
   ## Check for errors
   family <- match.arg(family)
@@ -22,6 +22,7 @@ grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD"
     group.multiplier <- group.multiplier[-nzg]    
   }
   XX <- XX[ ,nz, drop=FALSE]
+  group.orig <- group
   group <- group[nz]
   K <- as.numeric(table(group))
   if (strtrim(penalty,2)=="gr") XX <- orthogonalize(XX, group)
@@ -63,6 +64,7 @@ grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD"
   iter <- iter[ind]
   lambda <- lambda[ind]
   df <- df[ind]
+  loss <- loss[ind]
   if (warn & any(iter==max.iter)) warning("Algorithm failed to converge for all values of lambda")
 
   ## Unstandardize
@@ -80,7 +82,7 @@ grpreg <- function(X, y, group=1:ncol(X), penalty=c("grLasso", "grMCP", "grSCAD"
   
   structure(list(beta=beta,
                  family=family,
-                 group=group,
+                 group=group.orig,
                  lambda=lambda,
                  alpha=alpha,
                  loss = loss,
